@@ -7,8 +7,8 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 from .dicts import recursive_dict, scrub_dict, to_dict, recursive_dict_to_dict
-from .charset import int_to_charset, charset_to_int, change_charset
+from .charsets import int_to_charset, charset_to_int, change_charset
 from .numbers import is_hex, is_int, hex_to_int, int_to_hex
